@@ -43,10 +43,10 @@ typedef struct config {
 #define NOPORTLOG      0
 
 #define MAX_KERNEL_SIZE      0x200000
-#define MAX_ROMDISK_SIZE     0xA00000
-#define MAX_DOWNLOAD_SIZE    0x770000
+#define MAX_ROMDISK_SIZE     0xB00000
+#define MAX_DOWNLOAD_SIZE    0x670000
 
-#define SPLITFILE_OFFSET     0x600000
+#define SPLITFILE_OFFSET     0x500000
 
 #define SECTOR_SIZE          0x20000
 #define SECTOR_ALIGN(x) (x%SECTOR_SIZE) ? (x + (SECTOR_SIZE-(x%SECTOR_SIZE))) : x
