@@ -25,17 +25,34 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "vrerror.h"
 #include "vrfile.h"
 
-void vr_error(const char *msg, ...) {
+void
+vr_error (const char *msg, ...)
+{
 	va_list ap;
 	char buf[128];
-	
-	va_start(ap, msg);
-	vsnprintf(buf, 128, msg, ap);
-	if(errno) 
-		fprintf(stderr, "\n%s - %s\n\n", buf, strerror(errno));
-	else  
-		fprintf(stderr, "\n%s\n\n", buf);
-	va_end(ap);
 
-	vrfile_cleanup(1);
+	va_start (ap, msg);
+	vsnprintf (buf, 128, msg, ap);
+	if (errno)
+		fprintf (stderr, "\n%s - %s\n\n", buf, strerror (errno));
+	else
+		fprintf (stderr, "\n%s\n\n", buf);
+	va_end (ap);
+
+	vrfile_cleanup (1);
+}
+
+void
+vr_warning (const char *msg, ...)
+{
+	va_list ap;
+	char buf[128];
+
+	va_start (ap, msg);
+	vsnprintf (buf, 128, msg, ap);
+	if (errno)
+		fprintf (stderr, "\n%s - %s\n", buf, strerror (errno));
+	else
+		fprintf (stderr, "\n%s\n", buf);
+	va_end (ap);
 }
